MethodChannelFlutterQqLogin class
An implementation of FlutterQqLoginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterQqLoginPlatform
- MethodChannelFlutterQqLogin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getUserInfo(
String accessToken, String openid) → Future< String?> -
get qq user info
override
-
init(
String appId) → Future< void> -
init qq plugin
override
-
isInstalled(
) → Future< bool> -
check qq app is installed
override
-
login(
) → Future< String?> -
auth qq app
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited